summaryrefslogtreecommitdiffstats
path: root/Vlv2TbltDevicePkg/SmBiosMiscDxe/MiscSystemManufacturerFunction.c
diff options
context:
space:
mode:
Diffstat (limited to 'Vlv2TbltDevicePkg/SmBiosMiscDxe/MiscSystemManufacturerFunction.c')
-rw-r--r--Vlv2TbltDevicePkg/SmBiosMiscDxe/MiscSystemManufacturerFunction.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/Vlv2TbltDevicePkg/SmBiosMiscDxe/MiscSystemManufacturerFunction.c b/Vlv2TbltDevicePkg/SmBiosMiscDxe/MiscSystemManufacturerFunction.c
index 99906d0613..420c8c3932 100644
--- a/Vlv2TbltDevicePkg/SmBiosMiscDxe/MiscSystemManufacturerFunction.c
+++ b/Vlv2TbltDevicePkg/SmBiosMiscDxe/MiscSystemManufacturerFunction.c
@@ -93,9 +93,9 @@ AddSmbiosManuCallback (
ASSERT_EFI_ERROR (Status);
- if (BOARD_ID_MINNOW2_COMPATIBLE == mPlatformInfo->BoardId) {
- // Detect the board is compatible board platform
- UnicodeSPrint (PlatformNameBuffer, sizeof (PlatformNameBuffer),L"%s",L"Minnowboard Compatible ");
+ if (BOARD_ID_MINNOW2_TURBOT == mPlatformInfo->BoardId) {
+ // Detect the board is Turbot board platform
+ UnicodeSPrint (PlatformNameBuffer, sizeof (PlatformNameBuffer),L"%s",L"Minnowboard Turbot ");
} else {
UnicodeSPrint (PlatformNameBuffer, sizeof (PlatformNameBuffer),L"%s",L"Minnowboard Max ");
}
@@ -165,8 +165,8 @@ AddSmbiosManuCallback (
break;
}
- if (BOARD_ID_MINNOW2_COMPATIBLE == mPlatformInfo->BoardId) {
- UnicodeSPrint (Buffer, sizeof (Buffer),L"Compatible Vendor");
+ if (BOARD_ID_MINNOW2_TURBOT == mPlatformInfo->BoardId) {
+ UnicodeSPrint (Buffer, sizeof (Buffer),L"ADI");
HiiSetString(mHiiHandle,STRING_TOKEN(STR_MISC_SYSTEM_MANUFACTURER), Buffer, NULL);
}
TokenToGet = STRING_TOKEN (STR_MISC_SYSTEM_MANUFACTURER);